# lingcorp

CSV-based linguistic corpus annotation and search.

[![Versions](https://img.shields.io/pypi/pyversions/lingcorp)](https://www.python.org/)
[![PyPI](https://img.shields.io/pypi/v/lingcorp.svg)](https://pypi.org/project/lingcorp)
[![License](https://img.shields.io/github/license/fmatter/lingcorp)](https://www.apache.org/licenses/LICENSE-2.0)
[![Tests](https://img.shields.io/github/actions/workflow/status/fmatter/lingcorp/tests.yml?label=tests)](https://github.com/fmatter/lingcorp/actions/workflows/tests.yml)